@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class FinancialConfig(AppConfig):
-    name = 'zibal'
+    name = 'financial'
